@@ -98,9 +98,10 @@ def test_aggregation(books):
     counts = books[F.author.lower()].value_counts()
     assert dict(counts) == {'a': 2, 'b': 3}
     assert dict(counts[F('count') > 2]) == {'b': 3}
-    amounts = books[{F.quantity <= 1: 'low', F.quantity >= 10: 'high'}]
-    assert dict(amounts.value_counts()) == {'low': 1, None: 2, 'high': 2}
-    groups = books.groupby(amount={F.quantity <= 1: 'low', F.quantity >= 10: 'high', 'default': 'medium'})
+    case = {F.quantity <= 1: 'low', F.quantity >= 10: 'high'}
+    assert dict(books[case].value_counts()) == {'low': 1, None: 2, 'high': 2}
+    case['default'] = 'medium'
+    assert set(books.items(amount=case)) == {('low',), ('medium',), ('high',)}
     with pytest.raises(Exception):
         Case({models.Q(): None}).output_field
 
@@ -161,9 +162,9 @@ def test_functions(books):
 def test_2(books):
     row = books['id', 'author'].first()
     assert (row.id, row.author) == row
-    row = books['author',].min()
+    row = books[('author',)].min()
     assert (row.author__min,) == row
-    key, values = next(iter(books['quantity',].groupby('author')))
+    key, values = next(iter(books[('quantity',)].groupby('author')))
     assert next(values).quantity
     assert dict(books[F.author.find('A')].value_counts()) == {-1: 3, 0: 2}
 
@@ -260,6 +261,17 @@ def test_3():
     assert isinstance(F.x.md5, F)
 
 
+@pytest.mark.skipif(django.VERSION < (3, 2), reason='requires django >=3.2')
+def test_3_2(books):
+    assert isinstance(F.x.collate('nocase'), functions.Collate)
+    assert isinstance(F.json(), functions.JSONObject)
+    assert isinstance(F.random(), functions.Random)
+
+    case = {F.quantity <= 1: 'low', F.quantity >= 10: 'high', 'default': 'medium'}
+    assert list(books.alias(amount=case).order_by('amount')['quantity']) == [10, 10, 1, 2, 2]
+    assert books.alias(name=F.author.lower()).annotate(name=F('name'))
+
+
 def test_lookups(books):
     assert books[F.last_modified.year == timezone.now().year].count() == 5
     assert isinstance(F.quantity.min(), models.Min)
